# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner

class TestPivot200ResponseInner(unittest.TestCase):
    """Pivot200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Pivot200ResponseInner:
        """Test Pivot200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Pivot200ResponseInner`
        """
        model = Pivot200ResponseInner()
        if include_optional:
            return Pivot200ResponseInner(
                p = 1.337,
                r1 = 1.337,
                s1 = 1.337,
                r2 = 1.337,
                s2 = 1.337,
                r3 = 1.337,
                s3 = 1.337
            )
        else:
            return Pivot200ResponseInner(
        )
        """

    def testPivot200ResponseInner(self):
        """Test Pivot200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from tickcatcher.models.adx200_response_inner import Adx200ResponseInner
from tickcatcher.models.bbands200_response_inner import Bbands200ResponseInner
from tickcatcher.models.bbands_request import BbandsRequest
from tickcatcher.models.bbands_request_params import BbandsRequestParams
from tickcatcher.models.calendar_event import CalendarEvent
from tickcatcher.models.candle import Candle
from tickcatcher.models.ema_request import EmaRequest
from tickcatcher.models.ema_request_params import EmaRequestParams
from tickcatcher.models.heikenashi_request import HeikenashiRequest
from tickcatcher.models.ichimoku200_response_inner import Ichimoku200ResponseInner
from tickcatcher.models.ichimoku_request import IchimokuRequest
from tickcatcher.models.ichimoku_request_params import IchimokuRequestParams
from tickcatcher.models.info import Info
from tickcatcher.models.keltner_request import KeltnerRequest
from tickcatcher.models.keltner_request_params import KeltnerRequestParams
from tickcatcher.models.macd200_response_inner import Macd200ResponseInner
from tickcatcher.models.macd_request import MacdRequest
from tickcatcher.models.macd_request_params import MacdRequestParams
from tickcatcher.models.metadata import Metadata
from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner
from tickcatcher.models.psar_request import PsarRequest
from tickcatcher.models.psar_request_params import PsarRequestParams
from tickcatcher.models.search_result import SearchResult
from tickcatcher.models.sma_request import SmaRequest
from tickcatcher.models.sma_request_params import SmaRequestParams
from tickcatcher.models.stoch200_response_inner import Stoch200ResponseInner
from tickcatcher.models.stoch_request import StochRequest
from tickcatcher.models.stoch_request_params import StochRequestParams
from tickcatcher.models.supertrend200_response_inner import Supertrend200ResponseInner
from tickcatcher.models.supertrend_request import SupertrendRequest
from tickcatcher.models.supertrend_request_params import SupertrendRequestParams




# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.ultra_indicators_api import UltraIndicatorsApi


class TestUltraIndicatorsApi(unittest.TestCase):
    """UltraIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UltraIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_adx(self) -> None:
        """Test case for adx

        Calculate Average Directional Index (ADX)
        """
        pass

    def test_atr(self) -> None:
        """Test case for atr

        Calculate Average True Range (ATR)
        """
        pass

    def test_cci(self) -> None:
        """Test case for cci

        Calculate Commodity Channel Index (CCI)
        """
        pass

    def test_psar(self) -> None:
        """Test case for psar

        Calculate Parabolic SAR
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class Pivot200ResponseInner(BaseModel):
    """
    Pivot200ResponseInner
    """ # noqa: E501
    p: Optional[Union[StrictFloat, StrictInt]] = None
    r1: Optional[Union[StrictFloat, StrictInt]] = None
    s1: Optional[Union[StrictFloat, StrictInt]] = None
    r2: Optional[Union[StrictFloat, StrictInt]] = None
    s2: Optional[Union[StrictFloat, StrictInt]] = None
    r3: Optional[Union[StrictFloat, StrictInt]] = None
    s3: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["p", "r1", "s1", "r2", "s2", "r3", "s3"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Pivot200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if p (nullable) is None
        # and model_fields_set contains the field
        if self.p is None and "p" in self.model_fields_set:
            _dict['p'] = None

        # set to None if r1 (nullable) is None
        # and model_fields_set contains the field
        if self.r1 is None and "r1" in self.model_fields_set:
            _dict['r1'] = None

        # set to None if s1 (nullable) is None
        # and model_fields_set contains the field
        if self.s1 is None and "s1" in self.model_fields_set:
            _dict['s1'] = None

        # set to None if r2 (nullable) is None
        # and model_fields_set contains the field
        if self.r2 is None and "r2" in self.model_fields_set:
            _dict['r2'] = None

        # set to None if s2 (nullable) is None
        # and model_fields_set contains the field
        if self.s2 is None and "s2" in self.model_fields_set:
            _dict['s2'] = None

        # set to None if r3 (nullable) is None
        # and model_fields_set contains the field
        if self.r3 is None and "r3" in self.model_fields_set:
            _dict['r3'] = None

        # set to None if s3 (nullable) is None
        # and model_fields_set contains the field
        if self.s3 is None and "s3" in self.model_fields_set:
            _dict['s3'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Pivot200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "p": obj.get("p"),
            "r1": obj.get("r1"),
            "s1": obj.get("s1"),
            "r2": obj.get("r2"),
            "s2": obj.get("s2"),
            "r3": obj.get("r3"),
            "s3": obj.get("s3")
        })
        return _obj





# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.basic_indicators_api import BasicIndicatorsApi


class TestBasicIndicatorsApi(unittest.TestCase):
    """BasicIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BasicIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_ema(self) -> None:
        """Test case for ema

        Calculate Exponential Moving Average (EMA)
        """
        pass

    def test_rsi(self) -> None:
        """Test case for rsi

        Calculate Relative Strength Index (RSI)
        """
        pass

    def test_sma(self) -> None:
        """Test case for sma

        Calculate Simple Moving Average (SMA)
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.pro_indicators_api import ProIndicatorsApi


class TestProIndicatorsApi(unittest.TestCase):
    """ProIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_bbands(self) -> None:
        """Test case for bbands

        Calculate Bollinger Bands
        """
        pass

    def test_macd(self) -> None:
        """Test case for macd

        Calculate MACD
        """
        pass

    def test_stoch(self) -> None:
        """Test case for stoch

        Calculate Stochastic Oscillator
        """
        pass

    def test_volumema(self) -> None:
        """Test case for volumema

        Calculate Volume MA
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from tickcatcher.api.basic_indicators_api import BasicIndicatorsApi
from tickcatcher.api.calendar_api import CalendarApi
from tickcatcher.api.candles_api import CandlesApi
from tickcatcher.api.enterprise_indicators_api import EnterpriseIndicatorsApi
from tickcatcher.api.general_api import GeneralApi
from tickcatcher.api.mega_indicators_api import MegaIndicatorsApi
from tickcatcher.api.pro_indicators_api import ProIndicatorsApi
from tickcatcher.api.ultra_indicators_api import UltraIndicatorsApi




# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.mega_indicators_api import MegaIndicatorsApi


class TestMegaIndicatorsApi(unittest.TestCase):
    """MegaIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MegaIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_heikenashi(self) -> None:
        """Test case for heikenashi

        Calculate Heiken Ashi
        """
        pass

    def test_ichimoku(self) -> None:
        """Test case for ichimoku

        Calculate Ichimoku Cloud
        """
        pass

    def test_supertrend(self) -> None:
        """Test case for supertrend

        Calculate SuperTrend
        """
        pass

    def test_williamsr(self) -> None:
        """Test case for williamsr

        Calculate Williams %R
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictStr, field_validator
from typing import List
from tickcatcher.models.info import Info
from tickcatcher.models.metadata import Metadata
from tickcatcher.models.search_result import SearchResult

from tickcatcher.api_client import ApiClient, RequestSerialized
from tickcatcher.api_response import ApiResponse
from tickcatcher.rest import RESTResponseType


class GeneralApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Info:
        """Get your package information as well as your limitations

        Get your current RapidAPI package, which coins you can use, maximum candles that you can request, etc.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._info_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Info",
            '400': None,
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def info_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Info]:
        """Get your package information as well as your limitations

        Get your current RapidAPI package, which coins you can use, maximum candles that you can request, etc.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._info_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Info",
            '400': None,
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def info_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get your package information as well as your limitations

        Get your current RapidAPI package, which coins you can use, maximum candles that you can request, etc.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._info_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Info",
            '400': None,
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _info_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'rapidapiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/info',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def metadata(
        self,
        symbol: StrictStr,
        timeframe: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Metadata:
        """Get metadata of selected timeframe/symbol pair

        Retrieve metadata for a specific symbol and timeframe.

        :param symbol: (required)
        :type symbol: str
        :param timeframe: (required)
        :type timeframe: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._metadata_serialize(
            symbol=symbol,
            timeframe=timeframe,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Metadata",
            '400': None,
            '401': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def metadata_with_http_info(
        self,
        symbol: StrictStr,
        timeframe: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Metadata]:
        """Get metadata of selected timeframe/symbol pair

        Retrieve metadata for a specific symbol and timeframe.

        :param symbol: (required)
        :type symbol: str
        :param timeframe: (required)
        :type timeframe: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._metadata_serialize(
            symbol=symbol,
            timeframe=timeframe,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Metadata",
            '400': None,
            '401': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def metadata_without_preload_content(
        self,
        symbol: StrictStr,
        timeframe: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get metadata of selected timeframe/symbol pair

        Retrieve metadata for a specific symbol and timeframe.

        :param symbol: (required)
        :type symbol: str
        :param timeframe: (required)
        :type timeframe: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._metadata_serialize(
            symbol=symbol,
            timeframe=timeframe,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Metadata",
            '400': None,
            '401': None,
            '404': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _metadata_serialize(
        self,
        symbol,
        timeframe,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if symbol is not None:
            
            _query_params.append(('symbol', symbol))
            
        if timeframe is not None:
            
            _query_params.append(('timeframe', timeframe))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'rapidapiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/metadata',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def search(
        self,
        query: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[SearchResult]:
        """Search through the list of symbols to use correct one in the query

        If your queries don't work correctly, you can search the database with the coin name to get the correct symbol(s).

        :param query: (required)
        :type query: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_serialize(
            query=query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchResult]",
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_with_http_info(
        self,
        query: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[SearchResult]]:
        """Search through the list of symbols to use correct one in the query

        If your queries don't work correctly, you can search the database with the coin name to get the correct symbol(s).

        :param query: (required)
        :type query: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_serialize(
            query=query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchResult]",
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_without_preload_content(
        self,
        query: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search through the list of symbols to use correct one in the query

        If your queries don't work correctly, you can search the database with the coin name to get the correct symbol(s).

        :param query: (required)
        :type query: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_serialize(
            query=query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchResult]",
            '401': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_serialize(
        self,
        query,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            
            _query_params.append(('query', query))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'rapidapiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.3"

# Define package exports
__all__ = [
    "BasicIndicatorsApi",
    "CalendarApi",
    "CandlesApi",
    "EnterpriseIndicatorsApi",
    "GeneralApi",
    "MegaIndicatorsApi",
    "ProIndicatorsApi",
    "UltraIndicatorsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Adx200ResponseInner",
    "Bbands200ResponseInner",
    "BbandsRequest",
    "BbandsRequestParams",
    "CalendarEvent",
    "Candle",
    "EmaRequest",
    "EmaRequestParams",
    "HeikenashiRequest",
    "Ichimoku200ResponseInner",
    "IchimokuRequest",
    "IchimokuRequestParams",
    "Info",
    "KeltnerRequest",
    "KeltnerRequestParams",
    "Macd200ResponseInner",
    "MacdRequest",
    "MacdRequestParams",
    "Metadata",
    "Pivot200ResponseInner",
    "PsarRequest",
    "PsarRequestParams",
    "SearchResult",
    "SmaRequest",
    "SmaRequestParams",
    "Stoch200ResponseInner",
    "StochRequest",
    "StochRequestParams",
    "Supertrend200ResponseInner",
    "SupertrendRequest",
    "SupertrendRequestParams",
]

# import apis into sdk package
from tickcatcher.api.basic_indicators_api import BasicIndicatorsApi as BasicIndicatorsApi
from tickcatcher.api.calendar_api import CalendarApi as CalendarApi
from tickcatcher.api.candles_api import CandlesApi as CandlesApi
from tickcatcher.api.enterprise_indicators_api import EnterpriseIndicatorsApi as EnterpriseIndicatorsApi
from tickcatcher.api.general_api import GeneralApi as GeneralApi
from tickcatcher.api.mega_indicators_api import MegaIndicatorsApi as MegaIndicatorsApi
from tickcatcher.api.pro_indicators_api import ProIndicatorsApi as ProIndicatorsApi
from tickcatcher.api.ultra_indicators_api import UltraIndicatorsApi as UltraIndicatorsApi

# import ApiClient
from tickcatcher.api_response import ApiResponse as ApiResponse
from tickcatcher.api_client import ApiClient as ApiClient
from tickcatcher.configuration import Configuration as Configuration
from tickcatcher.exceptions import OpenApiException as OpenApiException
from tickcatcher.exceptions import ApiTypeError as ApiTypeError
from tickcatcher.exceptions import ApiValueError as ApiValueError
from tickcatcher.exceptions import ApiKeyError as ApiKeyError
from tickcatcher.exceptions import ApiAttributeError as ApiAttributeError
from tickcatcher.exceptions import ApiException as ApiException

# import models into sdk package
from tickcatcher.models.adx200_response_inner import Adx200ResponseInner as Adx200ResponseInner
from tickcatcher.models.bbands200_response_inner import Bbands200ResponseInner as Bbands200ResponseInner
from tickcatcher.models.bbands_request import BbandsRequest as BbandsRequest
from tickcatcher.models.bbands_request_params import BbandsRequestParams as BbandsRequestParams
from tickcatcher.models.calendar_event import CalendarEvent as CalendarEvent
from tickcatcher.models.candle import Candle as Candle
from tickcatcher.models.ema_request import EmaRequest as EmaRequest
from tickcatcher.models.ema_request_params import EmaRequestParams as EmaRequestParams
from tickcatcher.models.heikenashi_request import HeikenashiRequest as HeikenashiRequest
from tickcatcher.models.ichimoku200_response_inner import Ichimoku200ResponseInner as Ichimoku200ResponseInner
from tickcatcher.models.ichimoku_request import IchimokuRequest as IchimokuRequest
from tickcatcher.models.ichimoku_request_params import IchimokuRequestParams as IchimokuRequestParams
from tickcatcher.models.info import Info as Info
from tickcatcher.models.keltner_request import KeltnerRequest as KeltnerRequest
from tickcatcher.models.keltner_request_params import KeltnerRequestParams as KeltnerRequestParams
from tickcatcher.models.macd200_response_inner import Macd200ResponseInner as Macd200ResponseInner
from tickcatcher.models.macd_request import MacdRequest as MacdRequest
from tickcatcher.models.macd_request_params import MacdRequestParams as MacdRequestParams
from tickcatcher.models.metadata import Metadata as Metadata
from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner as Pivot200ResponseInner
from tickcatcher.models.psar_request import PsarRequest as PsarRequest
from tickcatcher.models.psar_request_params import PsarRequestParams as PsarRequestParams
from tickcatcher.models.search_result import SearchResult as SearchResult
from tickcatcher.models.sma_request import SmaRequest as SmaRequest
from tickcatcher.models.sma_request_params import SmaRequestParams as SmaRequestParams
from tickcatcher.models.stoch200_response_inner import Stoch200ResponseInner as Stoch200ResponseInner
from tickcatcher.models.stoch_request import StochRequest as StochRequest
from tickcatcher.models.stoch_request_params import StochRequestParams as StochRequestParams
from tickcatcher.models.supertrend200_response_inner import Supertrend200ResponseInner as Supertrend200ResponseInner
from tickcatcher.models.supertrend_request import SupertrendRequest as SupertrendRequest
from tickcatcher.models.supertrend_request_params import SupertrendRequestParams as SupertrendRequestParams




# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.models.sma_request_params import SmaRequestParams

class TestSmaRequestParams(unittest.TestCase):
    """SmaRequestParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SmaRequestParams:
        """Test SmaRequestParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SmaRequestParams`
        """
        model = SmaRequestParams()
        if include_optional:
            return SmaRequestParams(
                period = 56
            )
        else:
            return SmaRequestParams(
        )
        """

    def testSmaRequestParams(self):
        """Test SmaRequestParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.candles_api import CandlesApi


class TestCandlesApi(unittest.TestCase):
    """CandlesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CandlesApi()

    def tearDown(self) -> None:
        pass

    def test_basic_candles(self) -> None:
        """Test case for basic_candles

        Get candlestick data
        """
        pass

    def test_enterprise_candles(self) -> None:
        """Test case for enterprise_candles

        Get candlestick data
        """
        pass

    def test_mega_candles(self) -> None:
        """Test case for mega_candles

        Get candlestick data
        """
        pass

    def test_pro_candles(self) -> None:
        """Test case for pro_candles

        Get candlestick data
        """
        pass

    def test_ultra_candles(self) -> None:
        """Test case for ultra_candles

        Get candlestick data
        """
        pass


if __name__ == '__main__':
    unittest.main()
